@@ -6,7 +6,7 @@ CURL="curl --show-error --silent --location"
 
 echo "downloading bash_unit"
 current_working_dir=$PWD
-tarball_urls=$($CURL https://api.github.com/repos/pgrange/bash_unit/releases | grep tarball_url)
+tarball_urls=$($CURL https://api.github.com/repos/bash-unit/bash_unit/releases | grep tarball_url)
 tarball_url=$(echo "$tarball_urls" | head -n 1 | cut -d '"' -f 4)
 tmp_dir=$(mktemp -d 2>/dev/null || mktemp -d -t 'tmpdir')
 cd "$tmp_dir" || exit
